@@ -139,7 +139,7 @@ forecast <- function(timeS,
          is.list(preProcess) && length(preProcess) == 1 && inherits(preProcess[[1]], "trend")))
     stop("parameter preProcess must be NULL or a list of length 1 with a valid value")
 
-    # Check lags parameter
+  # Check lags parameter
   lagsc <- lags
   if (! (is.null(lagsc) || is.vector(lagsc, mode = "numeric"))) {
     stop("lags parameter should be NULL or numeric")
@@ -151,9 +151,9 @@ forecast <- function(timeS,
       partial <- stats::pacf(timeS, plot = FALSE)
       lagsc <- which(partial$acf > 2/ sqrt(length(timeS)))
       if (length(lagsc) == 0 ||
-          (length(lagsc) == 1 && 
-           what_preprocess(preProcess) %in% c("additive", "multiplicative"))) {
-        lagsc = 1:5
+          (length(lagsc) == 1 &&
+          what_preprocess(preProcess) %in% c("additive", "multiplicative"))) {
+        lagsc <- 1:5
       }
     }
   }
@@ -161,8 +161,13 @@ forecast <- function(timeS,
   if (lagsc[1] < 1) stop("lags values should be equal or greater than cero")
   
   if ((length(lagsc) == 1 && 
-       what_preprocess(preProcess) %in% c("additive", "multiplicative"))) {
-    stop("It does not make sense to use only 1 autoregressive lag with the additive or multiplicative transformation")
+      what_preprocess(preProcess) %in% c("additive", "multiplicative")) && 
+      transform_features(preProcess)) {
+    stop("It does not make sense to use only 1 autoregressive lag with the additive or multiplicative transformation of features")
+  }
+  
+  if (utils::tail(lagsc, 1) >= length(timeS)) {
+    stop("Maximum lag cannot be greater or equal to the length of the series")
   }
   
   # Check method parameter
@@ -205,6 +210,17 @@ forecast <- function(timeS,
     if (preprocessing_fd$differences == 0) {
       out <- build_examples(timeS, rev(lagsc))
     } else {
+      if (is.null(lags)) {
+        if (stats::frequency(preprocessing_fd$preprocessed) > 1) {
+          lagsc <- 1:stats::frequency(preprocessing_fd$preprocessed)
+        } else {
+          partial <- stats::pacf(preprocessing_fd$preprocessed, plot = FALSE)
+          lagsc <- which(partial$acf > 2/ sqrt(length(preprocessing_fd$preprocessed)))
+          if (length(lagsc) == 0) {
+            lagsc <- 1:5
+          }
+        }
+      }
       out <- build_examples(preprocessing_fd$preprocessed, rev(lagsc))
     }
     out$differences <- preprocessing_fd
@@ -212,9 +228,12 @@ forecast <- function(timeS,
     out <- build_examples(timeS, rev(lagsc))
     if (what_preprocess(preProcess) == "additive") {
       means <- rowMeans(out$features)
-      out$features <- sapply(1:nrow(out$features),
-                             function(row) out$features[row, ] - means[row])
-      out$features <- as.data.frame(t(out$features))
+      if (transform_features(preProcess)) { 
+        out$features <- sapply(1:nrow(out$features),
+                               function(row) out$features[row, ] - means[row])
+        out$features <- t(out$features)
+      }
+      out$features <- as.data.frame(out$features)
       out$targets <- out$targets - means
       # means <- rowMeans(out$features[, 1:length(lagsc)])
       # out$features[ , 1:length(lagsc)] <- sapply(1:nrow(out$features),
@@ -223,13 +242,17 @@ forecast <- function(timeS,
       # out$targets <- out$targets - means
     } else if (what_preprocess(preProcess) == "multiplicative") {
       means <- rowMeans(out$features)
-      out$features <- sapply(1:nrow(out$features),
-                             function(row) out$features[row, ] / means[row])
-      out$features <- as.data.frame(t(out$features))
+      if (transform_features(preProcess)) {
+        out$features <- sapply(1:nrow(out$features),
+                               function(row) out$features[row, ] / means[row])
+        out$features <- t(out$features)
+      }
+      out$features <- as.data.frame(out$features)
       out$targets <- out$targets / means
     }
   }
   if (!is.data.frame(out$features)) out$features <- as.data.frame(out$features)
+
   # Add other information to the output object
   out$call <- match.call()
   out$ts <- timeS
@@ -250,6 +273,7 @@ forecast <- function(timeS,
     out$tuneGrid <- result
     out$param <- as.list(result[which.min(result$RMSE), 1:ncol(tuneGrid), drop = FALSE])
   }
+
   # Create/train the model
   if (inherits(method, "function")) {
     # model provided by the user
@@ -262,21 +286,25 @@ forecast <- function(timeS,
   
   out$method <- method
   class(out) <- "utsf"
+
   # Prediction
   out$pred <- recursive_prediction(out, h = h)
   if (what_preprocess(preProcess) == "differences" && preprocessing_fd$differences > 0) {
     out$pred <- fd_unpreprocessing(out$pred, preprocessing_fd)
   }
+  
   # Estimate forecast accuracy
   if (!is.null(efa) && is.null(tuneGrid)){
-    out$efa <- estimate_accuracy(timeS = timeS, 
-                                 h = h, 
-                                 lags = lags,
-                                 method = method, 
-                                 param = param,
-                                 preProcess = preProcess, 
-                                 type = efa
+    r <- estimate_accuracy(timeS = timeS, 
+                           h = h, 
+                           lags = lags,
+                           method = method, 
+                           param = param,
+                           preProcess = preProcess, 
+                           type = efa
     )
+    out$global_efa <- r$global_efa
+    out$efa_per_horizon <- r$efa_per_horizon
   }
   out
 }
@@ -288,16 +316,25 @@ what_preprocess <- function(preProcess) {
   return(preProcess[[1]]$type)
 }
 
+transform_features <- function(preProcess) {
+  if (is.null(preProcess)) return(TRUE)
+  return(preProcess[[1]]$transform_features)
+}
+
 # @param object S3 object of class utsf
 predict_one_value_transforming <- function(object, example) {
   if (what_preprocess(object$preProcess) == "additive") {
     mean_ <- mean(example)
-    example <- example - mean_
+    if (transform_features(object$preProcess)) {
+      example <- example - mean_
+    }
     # mean_ <- mean(head(example, length(object$lags))) # añadido
     # example[seq_along(object$lags)] <- example[seq_along(object$lags)] - mean_ # añadido
   } else if (what_preprocess(object$preProcess) == "multiplicative") {
     mean_ <- mean(example)
-    example <- example / mean_
+    if (transform_features(object$preProcess)) {
+      example <- example / mean_
+    }
   }
   example <- as.data.frame(matrix(example, ncol = length(example)))
   colnames(example) <- colnames(object$features)
